# -*- coding: utf-8 -*-
from enum import Enum


class MessageProperty(Enum):
    TRACE_SWITCH = "TRACE_ON"
    MSG_REGION = "MSG_REGION"
    KEYS = "KEYS"
    TAGS = "TAGS"
    WAIT_STORE_MSG_OK = "WAIT"
    DELAY_TIME_LEVEL = "DELAY"
    RETRY_TOPIC = "RETRY_TOPIC"
    REAL_TOPIC = "REAL_TOPIC"
    REAL_QUEUE_ID = "REAL_QID"
    TRANSACTION_PREPARED = "TRAN_MSG"
    PRODUCER_GROUP = "PGROUP"
    MIN_OFFSET = "MIN_OFFSET"
    MAX_OFFSET = "MAX_OFFSET"
    BUYER_ID = "BUYER_ID"
    ORIGIN_MESSAGE_ID = "ORIGIN_MESSAGE_ID"
    TRANSFER_FLAG = "TRANSFER_FLAG"
    CORRECTION_FLAG = "CORRECTION_FLAG"
    MQ2_FLAG = "MQ2_FLAG"
    RECONSUME_TIME = "RECONSUME_TIME"
    UNIQ_CLIENT_MESSAGE_ID_KEYIDX = "UNIQ_KEY"
    MAX_RECONSUME_TIMES = "MAX_RECONSUME_TIMES"
    CONSUME_START_TIMESTAMP = "CONSUME_START_TIME"
